@@ -10,18 +10,8 @@ const project = new awscdk.AwsCdkConstructLibrary({
   license: 'MIT',
   cdkVersion: '2.37.0',
   defaultReleaseBranch: 'main',
-  keywords: [
-    'cdk',
-    'ecs',
-    'stepfunctions',
-    'route53',
-    'certbot',
-    'loadbalancer',
-  ],
-  devDeps: [
-    'aws-cdk',
-    'ts-node',
-  ],
+  keywords: ['cdk', 'ecs', 'stepfunctions', 'route53', 'certbot', 'loadbalancer'],
+  devDeps: ['aws-cdk', 'ts-node'],
   stability: 'experimental',
 
   python: {
@@ -37,6 +27,13 @@ const project = new awscdk.AwsCdkConstructLibrary({
       labels: ['auto-approve'],
     },
   },
+  prettier: true,
+  prettierOptions: {
+    settings: {
+      printWidth: 100,
+      singleQuote: true,
+    },
+  },
   projenrcTs: true,
 });
 
@@ -52,4 +49,4 @@ const testTask = project.tasks.tryFind('test');
 const newTestCommand = testTask!.steps[0]!.exec!.replace(' --updateSnapshot', '');
 testTask!.reset(newTestCommand);
 
-project.synth();
\ No newline at end of file
+project.synth();
