@@ -27,7 +27,7 @@ Edit settings in `examples/minimum.ts` and deploy the cdk construct. [Public hos
 git clone https://github.com/rajyan/low-cost-ecs.git
 yarn install
 # edit settings in bin/low-cost-ecs.ts
-./node_modules/.bin/cdk deploy
+cdk deploy
 ```
 
 Access the configured `recordDomainNames` and see that the Nginx sample server has been deployed.
@@ -212,7 +212,7 @@ class LowCostECS(
         :param record_domain_names: (experimental) Domain names for A records to elastic ip of ECS host instance. Default: - [ props.hostedZone.zoneName ]
         :param removal_policy: (experimental) Removal policy for the file system and log group (if using default). Default: - RemovalPolicy.DESTROY
         :param security_group: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
-        :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in createSampleTaskDefinition()
+        :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in sampleTaskDefinition()
         :param vpc: (experimental) Vpc of the ECS host instance and cluster. Default: - Creates vpc with only public subnets and no NAT gateways.
 
         :stability: experimental
@@ -349,7 +349,7 @@ class LowCostECSProps:
         :param record_domain_names: (experimental) Domain names for A records to elastic ip of ECS host instance. Default: - [ props.hostedZone.zoneName ]
         :param removal_policy: (experimental) Removal policy for the file system and log group (if using default). Default: - RemovalPolicy.DESTROY
         :param security_group: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
-        :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in createSampleTaskDefinition()
+        :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in sampleTaskDefinition()
         :param vpc: (experimental) Vpc of the ECS host instance and cluster. Default: - Creates vpc with only public subnets and no NAT gateways.
 
         :stability: experimental
@@ -544,8 +544,9 @@ class LowCostECSProps:
     ) -> typing.Optional["LowCostECSTaskDefinitionOptions"]:
         '''(experimental) Task definition for the server ecs task.
 
-        :default: - Nginx server task definition defined in createSampleTaskDefinition()
+        :default: - Nginx server task definition defined in sampleTaskDefinition()
 
+        :see: sampleTaskDefinition
         :stability: experimental
         '''
         result = self._values.get("server_task_definition")
